<?php

/**
 * @file
 * Allows to enable Views remote pager functionality for views displays.
 */

class vrp_plugin extends views_plugin_display_extender {

  /**
   * Default values.
   */
  function option_definition() {
    $options = parent::option_definition();
    $options['vrp_enabled'] = array('default' => TRUE);
    return $options;
  }
  function options_definition_alter(&$options) {
    $options['vrp_enabled'] = array('default' => array());
  }

  /**
   * Defines where within the Views admin UI the new settings will be visible.
   */
  function options_summary(&$categories, &$options) {
    #parent::options_summary($categories, $options);
    $categories['vrp'] = array(
      'title' => t('Remote pager'),
      'column' => 'second',
      'build' => array(
        '#weight' => 10,
      ),
    );
    $is_enabled = $this->vrp_enabled() ? t('Yes') : t('No');
    $options['vrp_enabled'] = array(
      'category' => 'vrp',
      'title' => t('Enable remote pager'),
      'value' => $is_enabled,
    );
  }

  function options_form(&$form, &$form_state) {
    $form['#title'] .= t('Remote pager');
    $form['vrp_enabled'] = array(
      '#type' => 'checkbox',
      '#title' => t('Enable remote pager'),
      '#default_value' => $this->vrp_enabled(),
      '#description' => t('Whether to provide virtual paging for nodes linked by this view.'),
    );
  }

  /**
   * Saves the form values.
   */
  function options_submit(&$form, &$form_state) {
    $this->display->set_option('vrp_enabled', $form_state['values']['vrp_enabled']);
  }

  /**
   * Returns the current setting.
   *
   * @return bool
   */
  protected function vrp_enabled() {
    return (bool) $this->display->get_option('vrp_enabled');
  }

}
